# Copyright (C) 2018 Avatao.com Innovative Learning Kft.
# All Rights Reserved. See LICENSE file for details.

from tfw.crypto import KeyManager, verify_message

from tfw.config.logs import logging

LOG = logging.getLogger(__name__)


class FSMAware:
    """
    Base class for stuff that has to be aware of the framework FSM.
    This is done by processing 'fsm_update' messages.
    """
    def __init__(self):
        self.fsm_state = None
        self.fsm_in_accepted_state = False
        self.fsm_last_update = None
        self._auth_key = KeyManager().auth_key

    def update_fsm_data(self, message):
        if message['key'] == 'fsm_update' and verify_message(self._auth_key, message):
            self._handle_fsm_update(message)
            return True
        return False

    def _handle_fsm_update(self, message):
        try:
            new_state = message['data']['current_state']
            if self.fsm_state != new_state:
                self.handle_fsm_step(**(message['data']))
            self.fsm_state = new_state
            self.fsm_in_accepted_state = message['data']['in_accepted_state']
            self.fsm_last_update = message['data']
        except KeyError:
            LOG.error('Invalid fsm_update message received!')

    def handle_fsm_step(self, **kwargs):
        """
        Called in case the TFW FSM has stepped.

        :param kwargs: fsm_update 'data' field
        """
        pass
